@@ -40,11 +40,11 @@ if (empty($lang) || !is_array($lang))
 //
 
 $lang = array_merge($lang, array(
-	'TRANSLATION_INFO'	=> 'Slovenský preklad: <a href="http://www.phpbb3.sk">phpbb3.sk</a> | <a href="http://www.phpbb.sk">phpbb.sk</a>.',
+	'TRANSLATION_INFO'	=> 'Slovenský preklad: <a href="http://www.senky.net/">Senky</a> & <a href="http://phpbb3hacks.com/">Kamahl</a>.',
 	'DIRECTION'			=> 'ltr',
 	'DATE_FORMAT'		=> '|d M Y|',	// 01 Jan 2007 (with Relative days enabled)
 	'USER_LANG'			=> 'sk',
-	
+
 	'1_DAY'			=> '1 deň',
 	'1_MONTH'		=> '1 mesiac',
 	'1_YEAR'		=> '1 rok',
@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Musíte uviesť predmet pri písaní novej správy.',
 	'ENABLED'							=> 'Povolené',
 	'ENCLOSURE'							=> 'Uzavreté',
+	'ENTER_USERNAME'					=> 'Zadajte užívateľské meno',
 	'ERR_CHANGING_DIRECTORY'			=> 'Nie je možné zmeniť adresár',
 	'ERR_CONNECTING_SERVER'				=> 'Chyba pri spojení so serverom',
 	'ERR_JAB_AUTH'						=> 'Nemôžem autorizovať užívateľa na Jabber serveri.',
@@ -190,7 +191,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'			=> 'Odoslaný formulár nebol platný. Pokúste sa ho odoslať znovu.',
 	'FORUM'					=> 'Fórum',
 	'FORUMS'				=> 'Fóra',
-	'FORUMS_MARKED'			=> 'Vybrané fóra boli označené ako prečítané',
+	'FORUMS_MARKED'			=> 'Fóra boli označené ako prečítané',
 	'FORUM_CAT'				=> 'Kategória fóra',
 	'FORUM_INDEX'			=> 'Obsah fóra',
 	'FORUM_LINK'			=> 'Odkaz na fórum',
@@ -200,6 +201,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'Prosím kliknite pre zobrazenie pravidiel fóra',
 	'FROM'					=> 'z',
 	'FSOCK_DISABLED'		=> 'Operácia nemohla byť dokončená, pretože funkcie <var>fsockopen</var> sú zakázané alebo hľadaný server nebol nájdený.',
+	'FSOCK_TIMEOUT'			=> 'Časový limit pre načítanie z prúdu siete vypršal.',
 
 	'FTP_FSOCK_HOST'				=> 'FTP server',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'FTP server používaný pre pripojenie k fóru',
@@ -289,7 +291,7 @@ $lang = array_merge($lang, array(
 
 	'KB'					=> 'KB',
   'KIB'					=> 'KiB',
-  
+
 	'LAST_POST'							=> 'Posledný príspevok',
 	'LAST_UPDATED'						=> 'Posledná aktualizácia',
 	'LAST_VISIT'						=> 'Posledná návšteva',
@@ -447,6 +449,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'				=> 'Čas odoslania',
 	'POST_TOPIC'			=> 'Odoslať novú tému',
 	'POST_UNAPPROVED'		=> 'Tento príspevok čaká na schválenie. Kliknite pre odsúhlasenie príspevku.',
+	'POWERED_BY'			=> 'Poháňa %s',
 	'PREVIEW'				=> 'Náhľad',
 	'PREVIOUS'				=> 'Predchádzajúci',// Použité pri stránkovaní
 	'PREVIOUS_STEP'			=> 'Predchádzajúci',
@@ -455,6 +458,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGES'		=> 'Súkromné správy',
 	'PRIVATE_MESSAGING'		=> 'Súkromné správy',
 	'PROFILE'				=> 'Užívateľský panel',
+	'RANK'						=> 'Hodnosť',
 
 	'READING_FORUM'				=> 'Prezerá témy v %s',
 	'READING_GLOBAL_ANNOUNCE'	=> 'Číta globálne oznámenie',
@@ -493,12 +497,12 @@ $lang = array_merge($lang, array(
 	'RETURN_PAGE'				=> '%sSpäť na predchádzajúcu stránku%s',
 	'RETURN_TOPIC'				=> '%sSpäť na naposledy navštívenú tému%s',
 	'RETURN_TO'					=> 'Späť na',
-	
+
 	'FEED'						=> 'ATOM',
 	'FEED_NEWS'				=> 'Novinky',
 	'FEED_TOPICS_ACTIVE'		=> 'Aktívne témy',
 	'FEED_TOPICS_NEW'			=> 'Nové témy',
-	
+
 	'RULES_ATTACH_CAN'			=> '<strong>Môžete</strong> prikladať súbory v tomto fóre',
 	'RULES_ATTACH_CANNOT'		=> '<strong>Nemôžete</strong> zasielať súbory v tomto fóre',
 	'RULES_DELETE_CAN'			=> '<strong>Môžete</strong> mazať svoje príspevky v tomto fóre',
@@ -571,7 +575,7 @@ $lang = array_merge($lang, array(
 	'TIME'				=> 'Čas',
 	'TOO_LARGE'						=> 'Zadaná hodnota je príliš veľká.',
 	'TOO_LARGE_MAX_RECIPIENTS'		=> 'Hodnota <strong>Maximálny počet povolených príjemcov súkromnej správy</strong> ktorú ste zadali, je príliš veľká.',
-	
+
 	'TOO_LONG'						=> 'Hodnota, ktorú ste zadali, je príliš dlhá.',
 	'TOO_LONG_AIM'					=> 'Zadané meno AIM je príliš dlhé.',
 	'TOO_LONG_CONFIRM_CODE'			=> 'Zadaný potvrdzovací kód je príliš dlhý.',
@@ -648,6 +652,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> neprečítaných správ',
 	'UNREAD_POST'			=> 'Neprečítaný príspevok',
 	'UNREAD_POSTS'			=> 'Neprečítané príspevky',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Naozaj chcete prestať sledovať toto fórum?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Naozaj chcete prestať sledovať fórum „%s“?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Naozaj chcete prestať sledovať túto tému?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Naozaj chcete prestať sledovať tému „%s“?',
 	'UNWATCHED_FORUMS'		=> 'Už nesledujete vybrané fóra.',
 	'UNWATCHED_TOPICS'		=> 'Už nesledujete vybrané témy.',
 	'UNWATCHED_FORUMS_TOPICS'   => 'Už nesledujete vybrané položky.',
@@ -696,19 +704,23 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'Varovania',
 	'WARN_USER'			=> 'Upozorniť užívateľa',
+	'WATCH_FORUM_CONFIRM'	=> 'Naozaj chcete sledovať toto fórum?',
+	'WATCH_FORUM_DETAILED'	=> 'Naozaj chcete sledovať fórum „%s“?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Naozaj chcete sledovať túto tému?',
+	'WATCH_TOPIC_DETAILED'	=> 'Naozaj chcete sledovať tému „%s“?',
 	'WELCOME_SUBJECT'	=> 'Vitajte na fóre %s',
 	'WEBSITE'			=> 'Internetová stránka',
 	'WHOIS'				=> 'Kto je to',
 	'WHO_IS_ONLINE'		=> 'Kto je on-line',
 	'WRONG_PASSWORD'	=> 'Zadali ste neplatné heslo.',
-	
+
 
 	'WRONG_DATA_ICQ'			=> 'Zadané číslo nie je správne číslo ICQ.',
 	'WRONG_DATA_JABBER'			=> 'Zadané meno nie je správne pre jabber účet.',
 	'WRONG_DATA_LANG'			=> 'Zadaný jazyk je neplatný.',
 	'WRONG_DATA_WEBSITE'		=> 'Zadaná adresa musí byť platná vrátane protokolu. Napríklad: http://www.example.com/.',
   'WROTE'             => 'píše',
-   
+
 	'YEAR'				=> 'Rok',
 	'YEAR_MONTH_DAY'	=> '(RRRR-MM-DD)',
 	'YES'				=> 'Áno',
